'use strict';

document.addEventListener('DOMContentLoaded', function() {

    var input_list = document.querySelectorAll('.search-field');

    for (var elem of input_list) {
        if (elem.getAttribute('type') == 'checkbox') {
            elem.addEventListener('change', searchReference);
        } else {
            elem.addEventListener('input', searchReference);
        }
    }

    var refs_list = document.querySelectorAll('.ref-line');

    for (var elem of refs_list) {
        elem.addEventListener('click', clickEventRef);
    }

    var param = extractQueryParam();

    var search_json = JSON.stringify(param);

    document.getElementById('export-payload').value = search_json;

 });


function searchReference() {
    var param = extractQueryParam();

    var search_json = JSON.stringify(param);

    document.getElementById('export-payload').value = search_json;

    var request = new HttpRequest({
        'url': '/search',
        'method': 'POST',
        'data': {
            'payload': JSON.stringify(param)
        }
    });

    request.done(updateResultData).send();
}

function updateResultData(data) {

    var resultTable = document.querySelector('#result-table tbody');

    while (resultTable.firstChild) {
        resultTable.removeChild(resultTable.firstChild);
    }

    data.forEach(function (ref) {

        if (ref.authority !== null) {
            ref.authority = ref.authority.name;
        }

        if (ref.reference_type !== null) {
            ref.reference_type = ref.reference_type.name;
        }


        ref.issued_date = formatDate(ref.issued_date)

        var newNode = Template.render('ref-line-template', ref);
        resultTable.appendChild(newNode);
        newNode.addEventListener('click', clickEventRef);
    });
}

/**
 * Extrai du DOM les param pour la recherche
 * @return {[type]} [description]
 */
function extractQueryParam() {

    var param = {};

    param.numero = document.getElementById('numero_id').value;
    param.title = document.getElementById('titre').value;
    param.dateAfter = document.getElementById('date-after').value;
    param.dateBefore = document.getElementById('date-before').value;

    param.authorities = [];

    var authorities_list = document.querySelectorAll('.authority-block input');

    for (var elem of authorities_list) {
        if (elem.checked) {
            param.authorities.push(elem.getAttribute('data-authority-slug'))
        }
    }

    param.types = [];

    var types_list = document.querySelectorAll('.type-block input');

    for (var elem of types_list) {
        if (elem.checked) {
            param.types.push(elem.getAttribute('data-type-slug'))
        }
    }

    return param;
}

function clickEventRef(evnt) {
    var node = evnt.currentTarget;

    var ref_id = node.getAttribute('data-ref-id');

    var request = new HttpRequest({
        'url': '/find-' + ref_id,
        'method': 'GET',
    });

    request.done(displayRefDialog).send();
}

function displayRefDialog(data) {

    // On supprime l'ancienne
    removeDialog();

    data.issued_date = formatDate(data.issued_date)

    // Puis on créé la nouvelle
    var newNode = Template.render('ref-dialog-template', data);
    document.getElementsByTagName('body')[0].appendChild(newNode);

    newNode.querySelector('.close-button').addEventListener('click', removeDialog);
}


function removeDialog() {
    var dialogNode = document.querySelector('.dialog-ref');

    if (dialogNode != null) {
        dialogNode.parentNode.removeChild(dialogNode);
    }
}


function formatDate(date_str) {
    if (typeof date_str == 'undefined' || date_str == null || date_str == 'null') {
        return '';
    }

    var date_array = date_str.split('-');

    return date_array.reverse().join('/');
}